<?php

use App\Http\Controllers\Admin\ArticuloController;
use App\Http\Controllers\Admin\CajaController;
use App\Http\Controllers\Admin\CierreController;
use App\Http\Controllers\Admin\CuadreRecesoController;
use App\Http\Controllers\Admin\EstudianteController;
use App\Http\Controllers\Admin\MenuController;
use App\Http\Controllers\Admin\ReporteController;
use App\Http\Controllers\ProductController;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {

    return redirect()->route('login');
})->name('home');

Auth::routes();


// rauta para ejecutar comando artisan desde la web
Route::get('artisan/{comando}/{contra}', function ($comando, $contra) {
    if ($contra === 'Taylor110eAA.') {
        // ejemplo www.decodev.net/cmd/migrate
        Artisan::call($comando);
        dd(Artisan::output());
    } else {
        echo 'NO ACCESO';
    }
});




Route::group(['prefix' => "admin", 'namespace' => 'App\Http\Controllers\Admin', 'middleware' => ['auth', 'AdminPanelAccess']], function () {

    Route::get('/', 'HomeController@index')->name('home');

    Route::resource('/users', 'UserController');
    Route::resource('/roles', 'RoleController');
    Route::resource('/permissions', 'PermissionController')->except(['show']);
});

Route::group(['prefix' => "caja", 'middleware' => ['auth', 'AdminPanelAccess']], function () {
    Route::get('inicio', [CajaController::class, 'create'])->name('caja.index');
    Route::post('store', [CajaController::class, 'store'])->name('caja.store');
    Route::DELETE('delete/{caja}', [CajaController::class, 'delete'])->name('caja.delete');
});

Route::group(['prefix' => "cuadre-receso", 'middleware' => ['auth', 'AdminPanelAccess']], function () {
    Route::get('inicio', [CuadreRecesoController::class, 'create'])->name('cr.create');
    Route::post('store', [CuadreRecesoController::class, 'store'])->name('cr.store');
    Route::DELETE('delete/{cuadre}', [CuadreRecesoController::class, 'delete'])->name('cr.delete');
});

Route::group(['prefix' => "cierre", 'middleware' => ['auth', 'AdminPanelAccess']], function () {
    Route::get('inicio', [CierreController::class, 'create'])->name('ci.create');
    Route::post('store', [CierreController::class, 'store'])->name('ci.store');
    Route::delete('delete/{cierre}', [CierreController::class, 'delete'])->name('ci.delete');
});

Route::group(['prefix' => "articulo", 'middleware' => ['auth', 'AdminPanelAccess']], function () {
    Route::get('inicio', [ArticuloController::class, 'index'])->name('arti.index');
    Route::get('valores', [ArticuloController::class, 'valores'])->name('arti.valores');
    Route::get('editar/{articulo}', [ArticuloController::class, 'edit'])->name('arti.edit');
    Route::post('store', [ArticuloController::class, 'store'])->name('arti.store');
    Route::post('storeValor/{articulo}', [ArticuloController::class, 'storeValor'])->name('arti.storeValor');
    Route::put('update/{articulo}', [ArticuloController::class, 'update'])->name('arti.update');
    Route::delete('delete/{articulo}', [ArticuloController::class, 'delete'])->name('arti.delete');


   
    
});

Route::group(['prefix' => "reporte", 'middleware' => ['auth', 'AdminPanelAccess']], function () {
    Route::get('index', [ReporteController::class, 'index'])->name('reporte.index');
    Route::get('movimiento_hoy', [ReporteController::class, 'movimiento_hoy'])->name('reporte.movimiento_hoy');
    Route::get('movimiento-filtrado', [ReporteController::class, 'getmovimientoToDate'])->name('reporte.getmovimientoToDate');
    Route::get('menus', [ReporteController::class, 'getMenuToFecha'])->name('reporte.getMenuToFecha');

    Route::get('entradas-report/', [ReporteController::class,  'getEntradaDeArticulos'])->name('arti.getEntradaDeArticulos');
    Route::get('salidas-report/', [ReporteController::class,   'getSalidaDeArticulos'])->name('arti.getSalidaDeArticulos');
    Route::get('articulos-report/', [ReporteController::class, 'getArticulos'])->name('arti.getArticulos');
});

Route::group(['prefix' => "menus", 'middleware' => ['auth', 'AdminPanelAccess']], function () {
    Route::get('index', [MenuController::class, 'index'])->name('menu.index');
    Route::post('store', [MenuController::class, 'store'])->name('menu.store');
    Route::delete('delete/{menu}', [MenuController::class, 'delete'])->name('menu.delete');
});


Route::controller(EstudianteController::class)->prefix('estudiante')->middleware(['auth', 'AdminPanelAccess'])->group(function () {
    Route::get('index', 'index')->name('estu.index');
    Route::get('perfil/{estudiante}', 'show')->name('estu.show');
    Route::get('balance/{estudiante}', 'balance')->name('estu.balance');
    Route::post('save', 'store')->name('estu.store');
    Route::put('update/{estudiante}', 'update')->name('estu.update');



    Route::post('create_abono', 'create_abono')->name('estu.create_abono');
    Route::delete('delete_abono/{abono}', 'delete_abono')->name('estu.delete_abono');
    Route::get('print/{abono}', 'printRecibo')->name('estu.printRecibo');
    Route::post('cretae_credito', 'cretae_credito')->name('estu.cretae_credito');
    Route::delete('delete_credito/{credito}', 'delete_credito')->name('estu.delete_credito');
});
